@@ -2,7 +2,7 @@ package Plack::Middleware::PrettyException;
 
 # ABSTRACT: Capture exceptions and present them as HTML or JSON
 
-our $VERSION = '1.009'; # VERSION
+our $VERSION = '1.010'; # VERSION
 
 use 5.010;
 use strict;
@@ -139,7 +139,21 @@ sub render_html_error {
             push(@more, "<li><strong>".($exception->message || 'unknown exception message')."</strong></li>");
             my $payload = $exception->payload;
             while (my ($k, $v) = each %$payload) {
-                push(@more,sprintf("<li>%s: %s</li>", $k, $v // ''));
+                if (ref($v)) {
+                    if (ref($v) eq 'ARRAY') {
+                        push(@more,sprintf("<li>%s:<ul>", $k ));
+                        foreach my $sv (@$v) {
+                            push(@more,sprintf("<li>%s</li>", $sv ));
+                        }
+                        push(@more,sprintf("</ul></li>"));
+                    }
+                    else {
+                        push(@more,sprintf("<li>%s which is an unhandled ref of %s</li>", $k, ref($v)));
+                    }
+                }
+                else {
+                    push(@more,sprintf("<li>%s: %s</li>", $k, $v // ''));
+                }
             }
         }
         if (@more) {
@@ -173,7 +187,7 @@ Plack::Middleware::PrettyException - Capture exceptions and present them as HTML
 
 =head1 VERSION
 
-version 1.009
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -434,7 +448,7 @@ Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 - 2021 by Thomas Klausner.
+This software is copyright (c) 2016 - 2022 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
